%global pgmajorversion 10
%global pgpackageversion %(echo %{pgmajorversion} | tr -d .)
%global sname repmgr
%global systemd_enabled 1

%if 0%{?fedora} > 29
%global pg_config PG_CONFIG=%_bindir/pg_server_config
%else
%global pg_config PG_CONFIG=%_bindir/pg_config
%endif

%global _config PG_CONFIG=%_bindir/pg_config

%global repmgr_config %{_sysconfdir}/%{sname}/%{sname}.conf
%global repmgr_logfiledir %{_localstatedir}/log/%{sname}/

%global major_version 5.0
%global minor_version 0

%global _varrundir %{_localstatedir}/run/%{sname}

Name:        %{sname}
Version:    %{major_version}.%{minor_version}
Release:    1%{nil}%{?dist}
Summary:    Replication Manager for PostgreSQL Clusters
License:    GPLv3+
URL:        https://repmgr.org
Source0:    https://repmgr.org/download/%{sname}-%{major_version}.%{minor_version}.tar.gz
Source1:    repmgr-pg%{pgpackageversion}.service
Source2:    repmgr-pg%{pgpackageversion}.init
Source3:    repmgr-pg%{pgpackageversion}.sysconfig

%if %{systemd_enabled}
BuildRequires:      systemd
# We require this to be present for %%{_prefix}/lib/tmpfiles.d
Requires:           systemd
Requires(post):     systemd-sysv
Requires(post):     systemd
Requires(preun):    systemd
Requires(postun):   systemd
%else
Requires(post):     chkconfig
Requires(preun):    chkconfig
# This is for /sbin/service
Requires(preun):    initscripts
Requires(postun):   initscripts
%endif
BuildRequires:    postgresql
BuildRequires:    postgresql-devel
BuildRequires:    libxslt-devel
BuildRequires:    pam-devel
BuildRequires:    openssl-devel
BuildRequires:    readline-devel
BuildRequires:    gcc
BuildRequires:    flex
# Missing ld libraries in %build
BuildRequires:    postgresql-static
BuildRequires:    libselinux-devel
BuildRequires:    krb5-devel

Requires:         postgresql-server

%if "%{pgpackageversion}" == "11" && 0%{?rhel} && 0%{?rhel} == 7
BuildRequires:  llvm-toolset-7
BuildRequires:  llvm5.0
%endif

%description
Repmgr is an open-source tool suite for managing replication and failover in a
cluster of PostgreSQL servers. It enhances PostgreSQL's built-in hot-standby
capabilities with tools to set up standby servers, monitor replication, and
perform administrative tasks such as failover or manual switchover operations.

%prep
%setup -q -n %{sname}-%{version}

%build

./configure %pg_config

%if %{systemd_enabled}
%make_build CFLAGS="%{optflags}" %pg_config USE_PGXS=1
%else
%{__make} %pg_config USE_PGXS=1 %{?_smp_mflags}
%endif

%install
%if %{systemd_enabled}
# Use new %%make_install macro:
USE_PGXS=1 %make_install  DESTDIR=%{buildroot}
%else
# Use older version
USE_PGXS=1 %{__make} install  DESTDIR=%{buildroot}
%endif
# Install sample conf file
%{__mkdir} -p %{buildroot}/%{_sysconfdir}/%{sname}/
install -m 644 repmgr.conf.sample %{buildroot}%{repmgr_config}

%if %{systemd_enabled}
install -d %{buildroot}%{_unitdir}
install -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service

# ... and make a tmpfiles script to recreate it at reboot.
%{__mkdir} -p %{buildroot}%{_tmpfilesdir}
cat > %{buildroot}%{_tmpfilesdir}/%{name}.conf <<EOF
d %{_varrundir} 0755 postgres postgres -
EOF

%else
install -d %{buildroot}%{_sysconfdir}/init.d
install -m 755 %{SOURCE2}  %{buildroot}%{_sysconfdir}/init.d/%{sname}
# Create the sysconfig directory and config file:
install -d -m 700 %{buildroot}%{_sysconfdir}/sysconfig/%{sname}/
install -m 600 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/%{sname}/%{sname}
%endif
# Create log directory:
install -d %{buildroot}%{repmgr_logfiledir}

%preun
%if %{systemd_enabled}
%systemd_preun %{sname}.service
%endif

%post
/sbin/ldconfig
%if %{systemd_enabled}
%systemd_post %{sname}.service
%tmpfiles_create_package %{sname} %{buildroot}%{_tmpfilesdir}/%{name}.conf
%else
# This adds the proper /etc/rc*.d links for the script
/sbin/chkconfig --add %{sname}
%endif
if [ ! -x %{_varrundir} ]
then
    %{__mkdir} -m 700 %{_varrundir}
    %{__chown} -R postgres: %{_varrundir}
fi

%postun -p /sbin/ldconfig
%if %{systemd_enabled}
%systemd_postrun %{sname}.service
%endif

%files
%attr(0700,postgres,postgres) %dir %{repmgr_logfiledir}
%if %{systemd_enabled}
%doc CREDITS HISTORY README.md
%license LICENSE
%else
%defattr(-,root,root,-)
%doc CREDITS HISTORY README.md LICENSE
%endif
%dir %{_sysconfdir}/%{sname}/
%config(noreplace) %{repmgr_config}
%{_bindir}/repmgr
%{_bindir}/repmgrd
%{_libdir}/pgsql/repmgr.so
%{_datadir}/pgsql/extension/
%if %{systemd_enabled}
%ghost %{_varrundir}
%{_tmpfilesdir}/%{name}.conf
%attr (644, root, root) %{_unitdir}/%{name}.service
%else
%{_sysconfdir}/init.d/%{sname}
%config(noreplace) %attr (600,root,root) %{_sysconfdir}/sysconfig/%{sname}/%{sname}
%endif

%changelog
* Sat Nov 09 2019 Michal Cyprian <mcyprian@redhat.com> - 5.0.0-1
- Update to version 5.0

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 4.3.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Tue Jun 18 2019 Michal Cyprian <mcyprian@redhat.com> - 4.3.0-2
- Fix changelog version

* Sun Apr 07 2019 Michal Cyprian <mcyprian@redhat.com> - 4.3.0-1
- Initial package
